==> react-bootstrap-multiselect-2.2.0.tgz: package/CHANGELOG.md <==
# Change Log

## [Unreleased](https://github.com/skratchdot/react-bootstrap-multiselect/tree/HEAD)

[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v2.1.0...HEAD)

**Closed issues:**

- Upgrade to new bootstrap-multiselect [\#43](https://github.com/skratchdot/react-bootstrap-multiselect/issues/43)

**Merged pull requests:**

- add onDeselectAll option [\#47](https://github.com/skratchdot/react-bootstrap-multiselect/pull/47) ([boatkorachal](https://github.com/boatkorachal))

## [v2.1.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v2.1.0) (2016-08-26)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v2.0.0...v2.1.0)

**Closed issues:**

- Inconsistent behavior with groups [\#41](https://github.com/skratchdot/react-bootstrap-multiselect/issues/41)

**Merged pull requests:**

- use option.label to set heading for optgroup not option.title [\#40](https://github.com/skratchdot/react-bootstrap-multiselect/pull/40) ([RaghavPro](https://github.com/RaghavPro))

## [v2.0.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v2.0.0) (2016-04-12)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v1.0.2...v2.0.0)

**Closed issues:**

- Invariant Violation: MultiSelect.render\(\): A valid ReactComponent must be returned. [\#36](https://github.com/skratchdot/react-bootstrap-multiselect/issues/36)
- Failed updating react-bootstra-multiselect because of unmet react dependency [\#34](https://github.com/skratchdot/react-bootstrap-multiselect/issues/34)

**Merged pull requests:**

- corrected typo enableCollapsibleOptGroups [\#37](https://github.com/skratchdot/react-bootstrap-multiselect/pull/37) ([belmer](https://github.com/belmer))

## [v1.0.2](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v1.0.2) (2016-03-14)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v1.0.1...v1.0.2)

**Closed issues:**

- enableFiltering not wokring [\#28](https://github.com/skratchdot/react-bootstrap-multiselect/issues/28)

**Merged pull requests:**

- Update gulp get-options [\#32](https://github.com/skratchdot/react-bootstrap-multiselect/pull/32) ([lvgunst](https://github.com/lvgunst))
- Add all possible bootstrap-multiselect options [\#31](https://github.com/skratchdot/react-bootstrap-multiselect/pull/31) ([lvgunst](https://github.com/lvgunst))
- add scss stylesheet [\#29](https://github.com/skratchdot/react-bootstrap-multiselect/pull/29) ([dmt0](https://github.com/dmt0))
- Update get-options.js [\#27](https://github.com/skratchdot/react-bootstrap-multiselect/pull/27) ([eaiero](https://github.com/eaiero))

## [v1.0.1](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v1.0.1) (2016-01-08)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v1.0.0...v1.0.1)

**Closed issues:**

- Page scrolls when list reaches end [\#23](https://github.com/skratchdot/react-bootstrap-multiselect/issues/23)
- React \>0.14.0 Warnings: .getDOMNode\(\) [\#21](https://github.com/skratchdot/react-bootstrap-multiselect/issues/21)

**Merged pull requests:**

- I added some options so they are accessible in react. [\#26](https://github.com/skratchdot/react-bootstrap-multiselect/pull/26) ([JohannesSanders](https://github.com/JohannesSanders))
- Update get-options.js [\#25](https://github.com/skratchdot/react-bootstrap-multiselect/pull/25) ([rkhayat](https://github.com/rkhayat))
- Update README.md [\#24](https://github.com/skratchdot/react-bootstrap-multiselect/pull/24) ([thataustin](https://github.com/thataustin))

## [v1.0.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v1.0.0) (2015-11-12)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.6.0...v1.0.0)

**Closed issues:**

- 'templates' option not working [\#20](https://github.com/skratchdot/react-bootstrap-multiselect/issues/20)

**Merged pull requests:**

- Allow the module to be used in Universal apps [\#22](https://github.com/skratchdot/react-bootstrap-multiselect/pull/22) ([angelaigreja](https://github.com/angelaigreja))

## [v0.6.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.6.0) (2015-09-16)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.5.0...v0.6.0)

**Closed issues:**

- buttonClass Prop ignored [\#18](https://github.com/skratchdot/react-bootstrap-multiselect/issues/18)

**Merged pull requests:**

- Added ability to re-render based on change in data or options [\#17](https://github.com/skratchdot/react-bootstrap-multiselect/pull/17) ([urvashi01](https://github.com/urvashi01))

## [v0.5.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.5.0) (2015-09-10)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.4.0...v0.5.0)

**Closed issues:**

- Few options don't work [\#15](https://github.com/skratchdot/react-bootstrap-multiselect/issues/15)

## [v0.4.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.4.0) (2015-08-25)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.3.0...v0.4.0)

**Merged pull requests:**

- Allow 'disabled' property to be toggled [\#14](https://github.com/skratchdot/react-bootstrap-multiselect/pull/14) ([netsgnut](https://github.com/netsgnut))
- Dropdown conflict fix [\#13](https://github.com/skratchdot/react-bootstrap-multiselect/pull/13) ([netsgnut](https://github.com/netsgnut))

## [v0.3.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.3.0) (2015-08-24)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.2.2...v0.3.0)

**Closed issues:**

- `templates` options not honoured? [\#12](https://github.com/skratchdot/react-bootstrap-multiselect/issues/12)

## [v0.2.2](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.2.2) (2015-07-03)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.2.1...v0.2.2)

**Closed issues:**

- How to get multiple selected values [\#6](https://github.com/skratchdot/react-bootstrap-multiselect/issues/6)

**Merged pull requests:**

- Partial solution to https://github.com/skratchdot/react-bootstrap-multiselect/issues/7 [\#8](https://github.com/skratchdot/react-bootstrap-multiselect/pull/8) ([tomaskikutis](https://github.com/tomaskikutis))

## [v0.2.1](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.2.1) (2015-05-15)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.2.0...v0.2.1)

**Closed issues:**

- The @jsx React.DOM pragma has been deprecated as of React 0.12 [\#5](https://github.com/skratchdot/react-bootstrap-multiselect/issues/5)

## [v0.2.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.2.0) (2015-04-03)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.1.2...v0.2.0)

**Closed issues:**

- Incompatibility with React 0.13 because of deprecated transferPropsTo method [\#4](https://github.com/skratchdot/react-bootstrap-multiselect/issues/4)

## [v0.1.2](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.1.2) (2015-02-20)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.1.1...v0.1.2)

## [v0.1.1](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.1.1) (2014-11-19)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.1.0...v0.1.1)

**Closed issues:**

- selected:true does not work [\#1](https://github.com/skratchdot/react-bootstrap-multiselect/issues/1)

**Merged pull requests:**

- added missing option [\#2](https://github.com/skratchdot/react-bootstrap-multiselect/pull/2) ([mfrye-intuit](https://github.com/mfrye-intuit))

## [v0.1.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.1.0) (2014-11-19)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.6...v0.1.0)

## [v0.0.6](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.6) (2014-09-04)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.5...v0.0.6)

## [v0.0.5](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.5) (2014-07-24)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.4...v0.0.5)

## [v0.0.4](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.4) (2014-07-24)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.3...v0.0.4)

## [v0.0.3](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.3) (2014-07-24)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.2...v0.0.3)

## [v0.0.2](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.2) (2014-07-23)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.1...v0.0.2)

## [v0.0.1](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.1) (2014-07-23)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> react-bootstrap-multiselect-2.3.0.tgz: package/CHANGELOG.md <==
# Change Log

## [v2.3.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v2.3.0) (2016-10-11)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v2.2.0...v2.3.0)

**Closed issues:**

- Extraneous props passed to select element, resulting in React warning [\#49](https://github.com/skratchdot/react-bootstrap-multiselect/issues/49)

## [v2.2.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v2.2.0) (2016-09-10)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v2.1.0...v2.2.0)

**Closed issues:**

- Upgrade to new bootstrap-multiselect [\#43](https://github.com/skratchdot/react-bootstrap-multiselect/issues/43)
- Require 'bootstrap-dropdown' causes conflict [\#39](https://github.com/skratchdot/react-bootstrap-multiselect/issues/39)

**Merged pull requests:**

- add onDeselectAll option [\#47](https://github.com/skratchdot/react-bootstrap-multiselect/pull/47) ([boatkorachal](https://github.com/boatkorachal))

## [v2.1.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v2.1.0) (2016-08-26)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v2.0.0...v2.1.0)

**Closed issues:**

- Inconsistent behavior with groups [\#41](https://github.com/skratchdot/react-bootstrap-multiselect/issues/41)

**Merged pull requests:**

- use option.label to set heading for optgroup not option.title [\#40](https://github.com/skratchdot/react-bootstrap-multiselect/pull/40) ([RaghavPro](https://github.com/RaghavPro))

## [v2.0.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v2.0.0) (2016-04-12)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v1.0.2...v2.0.0)

**Closed issues:**

- Invariant Violation: MultiSelect.render\(\): A valid ReactComponent must be returned. [\#36](https://github.com/skratchdot/react-bootstrap-multiselect/issues/36)
- Failed updating react-bootstra-multiselect because of unmet react dependency [\#34](https://github.com/skratchdot/react-bootstrap-multiselect/issues/34)

**Merged pull requests:**

- corrected typo enableCollapsibleOptGroups [\#37](https://github.com/skratchdot/react-bootstrap-multiselect/pull/37) ([belmer](https://github.com/belmer))

## [v1.0.2](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v1.0.2) (2016-03-14)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v1.0.1...v1.0.2)

**Closed issues:**

- enableFiltering not wokring [\#28](https://github.com/skratchdot/react-bootstrap-multiselect/issues/28)

**Merged pull requests:**

- Update gulp get-options [\#32](https://github.com/skratchdot/react-bootstrap-multiselect/pull/32) ([lvgunst](https://github.com/lvgunst))
- Add all possible bootstrap-multiselect options [\#31](https://github.com/skratchdot/react-bootstrap-multiselect/pull/31) ([lvgunst](https://github.com/lvgunst))
- add scss stylesheet [\#29](https://github.com/skratchdot/react-bootstrap-multiselect/pull/29) ([dmt0](https://github.com/dmt0))
- Update get-options.js [\#27](https://github.com/skratchdot/react-bootstrap-multiselect/pull/27) ([aiwb](https://github.com/aiwb))

## [v1.0.1](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v1.0.1) (2016-01-08)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v1.0.0...v1.0.1)

**Closed issues:**

- Page scrolls when list reaches end [\#23](https://github.com/skratchdot/react-bootstrap-multiselect/issues/23)
- React \>0.14.0 Warnings: .getDOMNode\(\) [\#21](https://github.com/skratchdot/react-bootstrap-multiselect/issues/21)

**Merged pull requests:**

- I added some options so they are accessible in react. [\#26](https://github.com/skratchdot/react-bootstrap-multiselect/pull/26) ([JohannesSanders](https://github.com/JohannesSanders))
- Update get-options.js [\#25](https://github.com/skratchdot/react-bootstrap-multiselect/pull/25) ([rkhayat](https://github.com/rkhayat))
- Update README.md [\#24](https://github.com/skratchdot/react-bootstrap-multiselect/pull/24) ([thataustin](https://github.com/thataustin))

## [v1.0.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v1.0.0) (2015-11-12)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.6.0...v1.0.0)

**Closed issues:**

- 'templates' option not working [\#20](https://github.com/skratchdot/react-bootstrap-multiselect/issues/20)

**Merged pull requests:**

- Allow the module to be used in Universal apps [\#22](https://github.com/skratchdot/react-bootstrap-multiselect/pull/22) ([angelaigreja](https://github.com/angelaigreja))

## [v0.6.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.6.0) (2015-09-16)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.5.0...v0.6.0)

**Closed issues:**

- buttonClass Prop ignored [\#18](https://github.com/skratchdot/react-bootstrap-multiselect/issues/18)

**Merged pull requests:**

- Added ability to re-render based on change in data or options [\#17](https://github.com/skratchdot/react-bootstrap-multiselect/pull/17) ([urvashi01](https://github.com/urvashi01))

## [v0.5.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.5.0) (2015-09-10)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.4.0...v0.5.0)

**Closed issues:**

- Few options don't work [\#15](https://github.com/skratchdot/react-bootstrap-multiselect/issues/15)

## [v0.4.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.4.0) (2015-08-25)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.3.0...v0.4.0)

**Merged pull requests:**

- Allow 'disabled' property to be toggled [\#14](https://github.com/skratchdot/react-bootstrap-multiselect/pull/14) ([netsgnut](https://github.com/netsgnut))
- Dropdown conflict fix [\#13](https://github.com/skratchdot/react-bootstrap-multiselect/pull/13) ([netsgnut](https://github.com/netsgnut))

## [v0.3.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.3.0) (2015-08-24)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.2.2...v0.3.0)

**Closed issues:**

- `templates` options not honoured? [\#12](https://github.com/skratchdot/react-bootstrap-multiselect/issues/12)

## [v0.2.2](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.2.2) (2015-07-03)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.2.1...v0.2.2)

**Closed issues:**

- How to get multiple selected values [\#6](https://github.com/skratchdot/react-bootstrap-multiselect/issues/6)

**Merged pull requests:**

- Partial solution to https://github.com/skratchdot/react-bootstrap-multiselect/issues/7 [\#8](https://github.com/skratchdot/react-bootstrap-multiselect/pull/8) ([tomaskikutis](https://github.com/tomaskikutis))

## [v0.2.1](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.2.1) (2015-05-15)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.2.0...v0.2.1)

**Closed issues:**

- The @jsx React.DOM pragma has been deprecated as of React 0.12 [\#5](https://github.com/skratchdot/react-bootstrap-multiselect/issues/5)

## [v0.2.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.2.0) (2015-04-03)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.1.2...v0.2.0)

**Closed issues:**

- Incompatibility with React 0.13 because of deprecated transferPropsTo method [\#4](https://github.com/skratchdot/react-bootstrap-multiselect/issues/4)

## [v0.1.2](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.1.2) (2015-02-20)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.1.1...v0.1.2)

## [v0.1.1](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.1.1) (2014-11-19)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.1.0...v0.1.1)

**Closed issues:**

- selected:true does not work [\#1](https://github.com/skratchdot/react-bootstrap-multiselect/issues/1)

**Merged pull requests:**

- added missing option [\#2](https://github.com/skratchdot/react-bootstrap-multiselect/pull/2) ([mfrye-intuit](https://github.com/mfrye-intuit))

## [v0.1.0](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.1.0) (2014-11-19)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.6...v0.1.0)

## [v0.0.6](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.6) (2014-09-04)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.5...v0.0.6)

## [v0.0.5](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.5) (2014-07-24)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.4...v0.0.5)

## [v0.0.4](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.4) (2014-07-24)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.3...v0.0.4)

## [v0.0.3](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.3) (2014-07-24)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.2...v0.0.3)

## [v0.0.2](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.2) (2014-07-23)
[Full Changelog](https://github.com/skratchdot/react-bootstrap-multiselect/compare/v0.0.1...v0.0.2)

## [v0.0.1](https://github.com/skratchdot/react-bootstrap-multiselect/tree/v0.0.1) (2014-07-23)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
